/* peggy -- a JPEG viewer for GGI
 *   Version 0.5
 *
 * Copyright 1997, 1998 Andreas Vogler
 * Completely re-written by Nathan Strong (gblues@gstis.net)
 *
 * This code is under GPL. Read LICENSE for more information
 */
#include "peggy.h"

/* The OPTIONS structure contains all settings that can be modified from
the command-line. (It also has some internal toggles that get set
automatically) It gets filled in by CheckCommandLine() in cmdline.c

Here we initialize it with program defaults:
	-640x480 resolution
	-0 second timeout (0 = wait for keypress)
	-no randomization (not re-implemented yet)
	-do not display version information
	-do not display help information
	-do not dither the image (this is set automatically if in 8bpp mode)
*/
struct OPTIONS Options = {640, 480, 0, 0, 0, 0, 0};
ggi_visual_t *vis;
ggi_mode mode;
extern void CheckCommandLine(int *argc, char **argv);
extern void DoJpeg(char *filename);
void InitGraphics(void);
void PrintVersion(void);
void PrintHelp(void);
int GetOptimumX(int x);
int GetComplement(int y);

int main(int argc, char **argv)
{
int i;
CheckCommandLine(&argc, argv);
if (Options.version)	PrintVersion();
else if (Options.help)	PrintHelp();
InitGraphics();
for (i=0; i<argc; i++)
	{
	DoJpeg(strdup(argv[i]));
	}
ggiClose(vis);
ggiExit();
exit(0);
}
/* PrintVersion() -- displays version information, then exits */
void PrintVersion(void) {
printf("Peggy -- a simple JPEG viewer for GGI\n");
printf("Version 0.5\n");
exit(0);
}
/* PrintHelp() -- displays help information, then exits */
void PrintHelp(void) {
printf("Peggy -- a simple JPEG viewer for GGI\n");
printf("USAGE:\npeggy [options] filename1 [filename2 ...]\n");
printf("Options:\n");
printf("\t--random: show files in a random order\t[default: disabled]\n");
printf("\t--time=N: set time delay to N seconds\t[default: 0]\n");
printf("\t--geometry=MxN: force MxN resolution\t[default: 320x200]\n");
printf("\t--version: displays version information\n");
printf("\t--help: this screen\n");
exit(0);
}
/* InitGraphics() -- makes sure resolution specified on the command line
is a legal resolution, then opens that resolution at the highest BPP
available from the display. If the display only supports 8bpp, dithering
is automatically enabled. */

void InitGraphics(void) {
int x = Options.xsize;
int y = Options.ysize;
if (!(( (x == 320)  && (y == 200) ) ||
     ( (x == 640)  && (y == 480) ) ||
     ( (x == 800)  && (y == 600) ) ||
     ( (x == 1024) && (y == 768) ) ||
     ( (x == 1280) && (y == 1024)) ||
     ( (x == 1600) && (y == 1200))) )
	{
	printf("Invalid mode: %dx%d\n", x, y);
	exit(1);
	}
ggiInit();
vis = ggiOpen(NULL);
if ( ggiCheckGraphMode(vis, x, y, x, y, GT_32BIT, &mode) )
  if ( ggiCheckGraphMode(vis, x, y, x, y, GT_24BIT, &mode) )
    if ( ggiCheckGraphMode(vis, x, y, x, y, GT_16BIT, &mode) )
      if ( ggiCheckGraphMode(vis, x, y, x, y, GT_15BIT, &mode) )
        if ( ggiCheckGraphMode(vis, x, y, x, y, GT_8BIT, &mode) )
	  {
	  ggiClose(vis);
	  ggiExit();
	  printf("Could not open %dx%d in 32, 24, 16, 15, or 8bpp.\n",
		x, y);
	  exit(1);
	  }
	else
	  {
	  Options.dither = 1;
	  ggiSetGraphMode(vis, x, y, x, y, GT_8BIT);
	  }
      else ggiSetGraphMode(vis, x, y, x, y, GT_15BIT);
    else ggiSetGraphMode(vis, x, y, x, y, GT_16BIT);
  else ggiSetGraphMode(vis, x, y, x, y, GT_24BIT);
else ggiSetGraphMode(vis, x, y, x, y, GT_32BIT);
}

